# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import detection_instance_api_pb2 as fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2


class DetectionInstanceApiStub(object):
    """import "fsai_grpc_api/protos/detection_api.proto";

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindOrCreateDetectionInstance = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateDetectionInstance',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceResponse.FromString,
                )
        self.GetDetectionInstancesByImageId = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstancesByImageId',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoBbox = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
                )
        self.DeleteDetectionInstanceById = channel.unary_unary(
                '/DetectionInstanceApi/DeleteDetectionInstanceById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
                )
        self.SetDetectionInstanceAsHumanVerified = channel.unary_unary(
                '/DetectionInstanceApi/SetDetectionInstanceAsHumanVerified',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdResponse.FromString,
                )


class DetectionInstanceApiServicer(object):
    """import "fsai_grpc_api/protos/detection_api.proto";

    """

    def FindOrCreateDetectionInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstancesByImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoBbox(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDetectionInstanceById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDetectionInstanceAsHumanVerified(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DetectionInstanceApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindOrCreateDetectionInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateDetectionInstance,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceResponse.SerializeToString,
            ),
            'GetDetectionInstancesByImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstancesByImageId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoBbox': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoBbox,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.SerializeToString,
            ),
            'DeleteDetectionInstanceById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDetectionInstanceById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.SerializeToString,
            ),
            'SetDetectionInstanceAsHumanVerified': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDetectionInstanceAsHumanVerified,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DetectionInstanceApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DetectionInstanceApi(object):
    """import "fsai_grpc_api/protos/detection_api.proto";

    """

    @staticmethod
    def FindOrCreateDetectionInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateDetectionInstance',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstancesByImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstancesByImageId',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoBbox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDetectionInstanceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/DeleteDetectionInstanceById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDetectionInstanceAsHumanVerified(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/SetDetectionInstanceAsHumanVerified',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.SetHumanVerifiedByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
