# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/query_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/query_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$fsai_grpc_api/protos/query_api.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"@\n\"DetectionsWithinBoundingBoxRequest\x12\x1a\n\x08geo_bbox\x18\x01 \x01(\x0b\x32\x08.GeoBbox\"\x7f\n\rQueryResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x1c\n\tgeo_point\x18\x03 \x01(\x0b\x32\t.GeoPoint\x12\x13\n\x0b\x63\x61tegory_id\x18\x04 \x01(\x05\x12\r\n\x05score\x18\x05 \x01(\x02\"V\n\x0eQueryResponses\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\"\n\ndetections\x18\x02 \x03(\x0b\x32\x0e.QueryResponse\"*\n\x1b\x44\x65tectionsAggregatedRequest\x12\x0b\n\x03wkt\x18\x01 \x01(\t\"\x91\x03\n\x1c\x44\x65tectionsAggregatedResponse\x12\x14\n\x0c\x64\x65tection_id\x18\x01 \x01(\x05\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x02 \x01(\x05\x12\x0b\n\x03lat\x18\x03 \x01(\x02\x12\x0b\n\x03lon\x18\x04 \x01(\x02\x12\x15\n\rcategory_name\x18\x05 \x01(\t\x12\x11\n\tmax_score\x18\x06 \x01(\x02\x12\x18\n\x10\x65stimated_height\x18\x07 \x01(\x02\x12\x15\n\rtotal_sources\x18\x08 \x01(\x05\x12\x16\n\x0ehuman_verified\x18\t \x01(\x08\x12.\n\nfirst_seen\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bvendor_name\x18\x0c \x01(\t\x12\x11\n\tvendor_id\x18\r \x01(\t\x12(\n\x07\x66\x65\x61ture\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct2\xbc\x01\n\x08QueryApi\x12V\n\x1eGetDetectionsWithinBoundingBox\x12#.DetectionsWithinBoundingBoxRequest\x1a\x0f.QueryResponses\x12X\n\x17GetDetectionsAggregated\x12\x1c.DetectionsAggregatedRequest\x1a\x1d.DetectionsAggregatedResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_DETECTIONSWITHINBOUNDINGBOXREQUEST = _descriptor.Descriptor(
  name='DetectionsWithinBoundingBoxRequest',
  full_name='DetectionsWithinBoundingBoxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='DetectionsWithinBoundingBoxRequest.geo_bbox', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=201,
)


_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='QueryResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='QueryResponse.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point', full_name='QueryResponse.geo_point', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_id', full_name='QueryResponse.category_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='QueryResponse.score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=330,
)


_QUERYRESPONSES = _descriptor.Descriptor(
  name='QueryResponses',
  full_name='QueryResponses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='QueryResponses.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detections', full_name='QueryResponses.detections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=418,
)


_DETECTIONSAGGREGATEDREQUEST = _descriptor.Descriptor(
  name='DetectionsAggregatedRequest',
  full_name='DetectionsAggregatedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wkt', full_name='DetectionsAggregatedRequest.wkt', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=462,
)


_DETECTIONSAGGREGATEDRESPONSE = _descriptor.Descriptor(
  name='DetectionsAggregatedResponse',
  full_name='DetectionsAggregatedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_id', full_name='DetectionsAggregatedResponse.detection_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance_id', full_name='DetectionsAggregatedResponse.detection_instance_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='DetectionsAggregatedResponse.lat', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lon', full_name='DetectionsAggregatedResponse.lon', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_name', full_name='DetectionsAggregatedResponse.category_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_score', full_name='DetectionsAggregatedResponse.max_score', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimated_height', full_name='DetectionsAggregatedResponse.estimated_height', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_sources', full_name='DetectionsAggregatedResponse.total_sources', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='human_verified', full_name='DetectionsAggregatedResponse.human_verified', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_seen', full_name='DetectionsAggregatedResponse.first_seen', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen', full_name='DetectionsAggregatedResponse.last_seen', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_name', full_name='DetectionsAggregatedResponse.vendor_name', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='DetectionsAggregatedResponse.vendor_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature', full_name='DetectionsAggregatedResponse.feature', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=866,
)

_DETECTIONSWITHINBOUNDINGBOXREQUEST.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_QUERYRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_QUERYRESPONSE.fields_by_name['geo_point'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_QUERYRESPONSES.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_QUERYRESPONSES.fields_by_name['detections'].message_type = _QUERYRESPONSE
_DETECTIONSAGGREGATEDRESPONSE.fields_by_name['first_seen'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONSAGGREGATEDRESPONSE.fields_by_name['last_seen'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONSAGGREGATEDRESPONSE.fields_by_name['feature'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['DetectionsWithinBoundingBoxRequest'] = _DETECTIONSWITHINBOUNDINGBOXREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
DESCRIPTOR.message_types_by_name['QueryResponses'] = _QUERYRESPONSES
DESCRIPTOR.message_types_by_name['DetectionsAggregatedRequest'] = _DETECTIONSAGGREGATEDREQUEST
DESCRIPTOR.message_types_by_name['DetectionsAggregatedResponse'] = _DETECTIONSAGGREGATEDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DetectionsWithinBoundingBoxRequest = _reflection.GeneratedProtocolMessageType('DetectionsWithinBoundingBoxRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETECTIONSWITHINBOUNDINGBOXREQUEST,
  '__module__' : 'fsai_grpc_api.protos.query_api_pb2'
  # @@protoc_insertion_point(class_scope:DetectionsWithinBoundingBoxRequest)
  })
_sym_db.RegisterMessage(DetectionsWithinBoundingBoxRequest)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.query_api_pb2'
  # @@protoc_insertion_point(class_scope:QueryResponse)
  })
_sym_db.RegisterMessage(QueryResponse)

QueryResponses = _reflection.GeneratedProtocolMessageType('QueryResponses', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESPONSES,
  '__module__' : 'fsai_grpc_api.protos.query_api_pb2'
  # @@protoc_insertion_point(class_scope:QueryResponses)
  })
_sym_db.RegisterMessage(QueryResponses)

DetectionsAggregatedRequest = _reflection.GeneratedProtocolMessageType('DetectionsAggregatedRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETECTIONSAGGREGATEDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.query_api_pb2'
  # @@protoc_insertion_point(class_scope:DetectionsAggregatedRequest)
  })
_sym_db.RegisterMessage(DetectionsAggregatedRequest)

DetectionsAggregatedResponse = _reflection.GeneratedProtocolMessageType('DetectionsAggregatedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DETECTIONSAGGREGATEDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.query_api_pb2'
  # @@protoc_insertion_point(class_scope:DetectionsAggregatedResponse)
  })
_sym_db.RegisterMessage(DetectionsAggregatedResponse)



_QUERYAPI = _descriptor.ServiceDescriptor(
  name='QueryApi',
  full_name='QueryApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=869,
  serialized_end=1057,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDetectionsWithinBoundingBox',
    full_name='QueryApi.GetDetectionsWithinBoundingBox',
    index=0,
    containing_service=None,
    input_type=_DETECTIONSWITHINBOUNDINGBOXREQUEST,
    output_type=_QUERYRESPONSES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionsAggregated',
    full_name='QueryApi.GetDetectionsAggregated',
    index=1,
    containing_service=None,
    input_type=_DETECTIONSAGGREGATEDREQUEST,
    output_type=_DETECTIONSAGGREGATEDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERYAPI)

DESCRIPTOR.services_by_name['QueryApi'] = _QUERYAPI

# @@protoc_insertion_point(module_scope)
