# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/metric_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2
from fsai_grpc_api.protos import mission_api_pb2 as fsai__grpc__api_dot_protos_dot_mission__api__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/metric_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%fsai_grpc_api/protos/metric_api.proto\x1a fsai_grpc_api/protos/utils.proto\x1a&fsai_grpc_api/protos/mission_api.proto\"\x1c\n\x0bMetricValue\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\">\n!FindMissionDetectionsCountRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"c\n\"FindMissionDetectionsCountResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.MetricValue2r\n\tMetricApi\x12\x65\n\x1a\x46indMissionDetectionCounts\x12\".FindMissionDetectionsCountRequest\x1a#.FindMissionDetectionsCountResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_mission__api__pb2.DESCRIPTOR,])




_METRICVALUE = _descriptor.Descriptor(
  name='MetricValue',
  full_name='MetricValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='MetricValue.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=143,
)


_FINDMISSIONDETECTIONSCOUNTREQUEST = _descriptor.Descriptor(
  name='FindMissionDetectionsCountRequest',
  full_name='FindMissionDetectionsCountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='FindMissionDetectionsCountRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=207,
)


_FINDMISSIONDETECTIONSCOUNTRESPONSE = _descriptor.Descriptor(
  name='FindMissionDetectionsCountResponse',
  full_name='FindMissionDetectionsCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindMissionDetectionsCountResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FindMissionDetectionsCountResponse.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=308,
)

_FINDMISSIONDETECTIONSCOUNTREQUEST.fields_by_name['mission'].message_type = fsai__grpc__api_dot_protos_dot_mission__api__pb2._MISSION
_FINDMISSIONDETECTIONSCOUNTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDMISSIONDETECTIONSCOUNTRESPONSE.fields_by_name['value'].message_type = _METRICVALUE
DESCRIPTOR.message_types_by_name['MetricValue'] = _METRICVALUE
DESCRIPTOR.message_types_by_name['FindMissionDetectionsCountRequest'] = _FINDMISSIONDETECTIONSCOUNTREQUEST
DESCRIPTOR.message_types_by_name['FindMissionDetectionsCountResponse'] = _FINDMISSIONDETECTIONSCOUNTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetricValue = _reflection.GeneratedProtocolMessageType('MetricValue', (_message.Message,), {
  'DESCRIPTOR' : _METRICVALUE,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:MetricValue)
  })
_sym_db.RegisterMessage(MetricValue)

FindMissionDetectionsCountRequest = _reflection.GeneratedProtocolMessageType('FindMissionDetectionsCountRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONDETECTIONSCOUNTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionDetectionsCountRequest)
  })
_sym_db.RegisterMessage(FindMissionDetectionsCountRequest)

FindMissionDetectionsCountResponse = _reflection.GeneratedProtocolMessageType('FindMissionDetectionsCountResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONDETECTIONSCOUNTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionDetectionsCountResponse)
  })
_sym_db.RegisterMessage(FindMissionDetectionsCountResponse)



_METRICAPI = _descriptor.ServiceDescriptor(
  name='MetricApi',
  full_name='MetricApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=310,
  serialized_end=424,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindMissionDetectionCounts',
    full_name='MetricApi.FindMissionDetectionCounts',
    index=0,
    containing_service=None,
    input_type=_FINDMISSIONDETECTIONSCOUNTREQUEST,
    output_type=_FINDMISSIONDETECTIONSCOUNTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_METRICAPI)

DESCRIPTOR.services_by_name['MetricApi'] = _METRICAPI

# @@protoc_insertion_point(module_scope)
